diff -r -u mdss/mdss_fb.c android_kernel_motorola_msm8937/drivers/video/msm/mdss/mdss_fb.c
--- mdss/mdss_fb.c	2019-01-24 20:56:07.984371000 +0100
+++ android_kernel_motorola_msm8937/drivers/video/msm/mdss/mdss_fb.c	2019-01-24 21:06:44.513242695 +0100
@@ -1962,7 +1962,7 @@
 		if (is_panel_split(mfd) && pdata->next)
 			mdss_fb_validate_split(pdata->panel_info.xres,
 					pdata->next->panel_info.xres, mfd);
-		mdss_panelinfo_to_fb_var(panel_info, var);
+		mdss_panelinfo_to_fb_var(mfd);
 		if (mdss_fb_send_panel_event(mfd, MDSS_EVENT_CHECK_PARAMS,
 							panel_info))
 			pr_err("Failed to send panel event CHECK_PARAMS\n");
@@ -2077,7 +2077,7 @@
 		 * programmed in the controller.
 		 * Update this info in the upstream structs.
 		 */
-		mdss_panelinfo_to_fb_var(panel_info, var);
+		mdss_panelinfo_to_fb_var(mfd);
 
 		/* Start the work thread to signal idle time */
 		if (mfd->idle_time)
@@ -2807,7 +2807,7 @@
 		return ret;
 	}
 
-	mdss_panelinfo_to_fb_var(panel_info, var);
+	mdss_panelinfo_to_fb_var(mfd);
 
 	fix->type = panel_info->is_3d_panel;
 	if (mfd->mdp.fb_stride)
@@ -3512,7 +3512,7 @@
 	}
 	var->xres_virtual = var->xres;
 	var->yres_virtual = pinfo->yres * mfd->fb_page;
-	mdss_panelinfo_to_fb_var(pinfo, var);
+	mdss_panelinfo_to_fb_var(mfd);
 }
 
 int mdss_fb_atomic_commit(struct fb_info *info,
@@ -3731,9 +3731,14 @@
 		pinfo->mipi.dsi_pclk_rate = pinfo->clk_rate;
 }
 
-void mdss_panelinfo_to_fb_var(struct mdss_panel_info *pinfo,
-						struct fb_var_screeninfo *var)
+void mdss_panelinfo_to_fb_var(struct msm_fb_data_type *mfd)
 {
+	if (!mfd)
+		return -EINVAL;
+
+	struct mdss_panel_info *pinfo = mfd->panel_info;
+	struct fb_info *fbi = mfd->fbi;
+	struct fb_var_screeninfo *var = &fbi->var;
 	u32 frame_rate;
 
 	var->xres = mdss_fb_get_panel_xres(pinfo);
@@ -3767,7 +3772,14 @@
 	if (pinfo->physical_height)
 		var->height = pinfo->physical_height;
 
-	pr_debug("ScreenInfo: res=%dx%d [%d, %d] [%d, %d]\n",
+	//Hack to update current fbi->mode according to fbi->var when var is updated from panel info
+	if (fbi->mode) {
+		printk("Updating mdss fb mode from fb var\n");
+		fb_var_to_videomode(fbi->mode, var);
+	}
+
+	printk("ScreenInfo: res=%dx%d [%d, %d] [%d, %d]\n",
+
 		var->xres, var->yres, var->left_margin,
 		var->right_margin, var->upper_margin,
 		var->lower_margin);
diff -r -u mdss/mdss_fb.h android_kernel_motorola_msm8937/drivers/video/msm/mdss/mdss_fb.h
--- mdss/mdss_fb.h	2019-01-24 20:56:07.984371000 +0100
+++ android_kernel_motorola_msm8937/drivers/video/msm/mdss/mdss_fb.h	2019-01-24 21:07:52.105682759 +0100
@@ -449,6 +449,5 @@
 
 u32 mdss_fb_get_mode_switch(struct msm_fb_data_type *mfd);
 void mdss_fb_report_panel_dead(struct msm_fb_data_type *mfd);
-void mdss_panelinfo_to_fb_var(struct mdss_panel_info *pinfo,
-						struct fb_var_screeninfo *var);
+void mdss_panelinfo_to_fb_var(struct msm_fb_data_type *mfd);
 #endif /* MDSS_FB_H */
diff -r -u mdss/mdss_mdp_overlay.c android_kernel_motorola_msm8937/drivers/video/msm/mdss/mdss_mdp_overlay.c
--- mdss/mdss_mdp_overlay.c	2019-01-24 20:56:08.004371000 +0100
+++ android_kernel_motorola_msm8937/drivers/video/msm/mdss/mdss_mdp_overlay.c	2019-01-24 21:08:47.682038150 +0100
@@ -2982,7 +2982,7 @@
 	 * data, so any further call to get the screen
 	 * info has the updated timings.
 	 */
-	mdss_panelinfo_to_fb_var(&pdata->panel_info, var);
+	mdss_panelinfo_to_fb_var(mfd);
 
 	MDSS_XLOG(dfps);
 	mutex_unlock(&mdp5_data->dfps_lock);

